@@ -9,16 +9,17 @@ import publication
 import typing_extensions
 
 import aws_cdk.aws_certificatemanager._jsii
+import aws_cdk.aws_cloudwatch._jsii
+import aws_cdk.aws_ec2._jsii
 import aws_cdk.aws_iam._jsii
-import aws_cdk.aws_lambda._jsii
 import aws_cdk.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-cdk/aws-apigatewayv2",
-    "1.64.0",
+    "1.117.0",
     __name__[0:-6],
-    "aws-apigatewayv2@1.64.0.jsii.tgz",
+    "aws-apigatewayv2@1.117.0.jsii.tgz",
 )
 
 __all__ = [
